<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Tanca (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Redueix</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandeix</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Descarta l&apos;alerta</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln paraula</numerusform>
            <numerusform>%Ln paraules</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minuts</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% de %Ln minut</numerusform>
            <numerusform>%L1% de %Ln minuts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% de %Ln paraula</numerusform>
            <numerusform>%L1% de %Ln paraules</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progrés diari</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>La ratxa més llarga</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Ratxa actual</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>No disponible</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dia</numerusform>
            <numerusform>%n dies</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% de l&apos;objectiu del dia</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Configura l&apos;idioma</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sense títol %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%! (Només lectura)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Disculpes</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>No s&apos;ha pogut desar &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Anomena i desa</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>No s&apos;ha pogut sobreescriure &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Reanomena el fitxer</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>No s&apos;ha pogut reanomenar &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Voleu recarregar el fitxer?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Voleu recarregar el fitxer &apos;%1&apos; des del disc?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Es perdran tots els canvis.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Torna a carregar</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sense títol %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Si deseu com a text pla es perdran tots els canvis de format. Voleu descartar el formatatge?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>S&apos;ha canviat el fitxer</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>El fitxer &apos;%1&apos; ha estat modificat per un altre programa.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Este segur que voleu tornar a carregar el fitxer?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Torna a carregar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>S&apos;ha esborrat el fitxer</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Un altre programa ha esborrat el fitxer %1</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Voleu tancar o desar el fitxer?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>No es pot obrir el fitxer</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Reemplaça amb:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignora majúscules</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Només paraules senceres</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expressions regulars</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Cerca cap enrere</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Cerca cap endavant</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Reemplaça</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Reemplaça-ho tot</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Troba</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Reemplaça</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Esteu segur que voleu reemplaçar %n instàncies?</numerusform>
            <numerusform>Esteu segur que voleu reemplaçar %n instàncies?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Disculpeu</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>No s&apos;ha trobat la frase</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Text d&apos;OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Format de text enriquit</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Text senzill</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Tots els fitxers</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Tots els fitxers compatibles</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>XML pla d&apos;OpenDocument</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Comprova l&apos;ortografia</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(No s&apos;han trobat suggeriments)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Obre la imatge</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Imatges (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccioneu l&apos;idioma de l&apos;aplicació:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Call que reinicieu l&apos;aplicació perquè tingui efecte el canvi d&apos;idioma</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>No s&apos;ha pogut obrir el fitxer</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadístiques</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra d&apos;eines</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Ortografia</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Seleccioneu un diccionari</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Disculpeu</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>És impossible obrir el fitxer</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>El fitxer no conté un diccionari que es pugui utilitzar</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Hi ha un conflicte entre dreceres. Esteu segur que voleu continuar?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Ja existeix el diccionari &apos;%1&apos;. Voleu reemplaçar-lo?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Objectiu del dia</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuts:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Paraules:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Sempre centrat verticalment</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Cursor d&apos;inserció de bloc</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Lletres suaus</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>So de màquina d&apos;escriure</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Cometes tipogràfiques:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doble</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Senzill</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Escenes</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Divisor</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>S&apos;està desant</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Recorda la posició del cursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Recompte de paraules</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Recompte de pàgines</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Recompte de paràgrafs</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Recompte de caràcters</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caràcters:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paràgrafs:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algorisme de recompte de paraules</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Voleu reiniciar a zero el progrés diari d&apos;avui?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Escriu la marca d&apos;ordre dels bits en els arxius de text pla</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Format per defecte:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Reinicia avui</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Recorda l&apos;historial</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mostra les ratxes</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progrés mínim per les ratxes:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detecta els límits de les paraules</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Divideix el nombre de caràcters entre sis</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Compta cada lletra com si fos una paraula</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algorisme de recompte de pàgines</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estil</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Només icones</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Només text</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Text al costat de les icones</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Text sota les icones</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posició del text:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Accions</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Puja</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Afegeix separador</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Ordre</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Drecera</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Comprova l&apos;ortografia mentre s&apos;escriu</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignaora les paraules en MAJÚSCULES</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignora les paraules amb números</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Diccionari personal</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Aquest fitxer no és un RTF suportat</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>S&apos;ha arribat inesperadament al final del fitxer</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Puja les escenes</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Commuta la llista d&apos;escenes</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Mostra la llista d&apos;escenes (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Oculta la llista d&apos;escenes (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Baixa les escenes</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Redimensiona la llista d&apos;escenes</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestiona les sessions</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essions</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Canvia a </translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Sessió nova</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Canvia el nom de la sessió</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Esteu segur que voleu eliminar la sessió seleccionada?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nom de la sessió:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Disculpes</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>El nom de la sessió seleccionat ja està essent utilitzat.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nou...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maj+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>Administrar</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Maj+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Neteja</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Reinicia a per defecte</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Drecera:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Reemplaça cometes ...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espereu siusplau</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Comprova l&apos;ortografia</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Afegeix</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignora</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnora-ho tot</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Canvia</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Canvia-ho tot</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>No s&apos;ha trobat al diccionari:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Canvia per:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>S&apos;està comprovant l&apos;ortografia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Espereu siusplau</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Voleu continuar comprovant des del principi del fitxer?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>S&apos;ha completat la revisió ortogràfica</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Símbols</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Símbols utilitzats darrerament</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Tots els símbols</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insereix</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sensetítol %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Sense imatge</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>En mosaic</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrada</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Estirada</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Escalada</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Aplica el zoom</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Margins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Above:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Below:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Esborra</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imatge:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>píxels</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dreta</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Tipus de lletra:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Error ortogràfic</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Espai entre línies</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Senzill</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 Línies</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doble</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Espai entre paràgrafs</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Amplada de la pestanya:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temes</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Per defecte</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Old School</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Nou</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished">Edita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importa Tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exporta Tema</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Voleu eliminar el temporitzador?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paraules:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pàgines:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paràgrafs:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caràcters:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ajusta el retard</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Ajusta  el temps</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Retard:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Temps:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarma</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memoràndum</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Esborra</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>No hi ha cap temporitzador en marxa</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Temporitzadors</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recent</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Voleu cancel·lar els temporitzadors existents?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>S&apos;estan carregant els Temes</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>S&apos;estan carregant els sons</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sense títol</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>bre fitxer</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Sobre FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un processador de text senzill a pantalla completa</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicat sota llicència  &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Usa les icones del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilitzades sota llicència &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caràcters: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Pàgines: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paràgrafs: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Paraules: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>&apos;està obrint %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sense títol %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Llista tots els documents</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Canvia a un document nou</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Canvia al document anterior</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Canvia al primer document</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Canvia al darrer document</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Canvia al document %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>S&apos;estan carregant els ajustos</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>No es pot escriure a la memòria cau d&apos;emergència.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter no es va tancat correctament.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Voleu restaurar des de la memòria cau d&apos;emergència?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>No s&apos;han pogut obrir alguns fitxers.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>S&apos;han obert alguns fitxers en mode de Només lectura.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos;és més nou que la còpia de la memòria cau.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Voleu sobreescriure el fitxer més nou?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Voleu desar els canvis?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Voleu desar els canvis efectuats a &apos;%1&apos; abans de tancar?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Es perdran els canvis si no els deseu.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>No s&apos;han pogut carregar els sons de màquina d&apos;escriure.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Obre</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Torna a carregar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Desa</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Desa &amp;com...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Reanomena...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Desa-ho tot</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestiona les sessions</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova sessió</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;primeix</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refés</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Talla</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Enganxa sense format</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Seleccion&amp;a tot</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Selecciona l&apos;escena</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmat</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>Itàlica</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>S&amp;ubratllat</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Ratllat</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Sup&amp;eríndex</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Subíndex</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Alinea a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Alinea al &amp;Centre</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Alinea a la dreta</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justifica</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Disminueix el sagnat</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>I&amp;ncrementa el sagnat</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Escriure d&apos;esquerra a dreta</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Escriure de dreta a esquerra</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Eines</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Cerca el següent</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Cerca l&apos;anterior</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Reemplaça</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Cometes tipogràfiques</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Actualitza el document</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Actualitza la selecció</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Ortografia</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Configuració i Idioma</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Temporitzadors</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ímbols...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Progrés diari</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostra la barra d&apos;eines</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Mostra les icones del menú</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Text focalitzat</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimitza</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temes...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferències...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>No focalitzis</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focalitza una línia</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focalitza tres línies</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paràgraf</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focalitza un paràgraf</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Idioma de l&apos;aplicació</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Alguns fitxers no tenen suport i no es podran obrir</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Una &amp;Línia</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tres línies</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
